@@ -57,13 +57,13 @@ dv_vs_ipred <- function(xpdb,
   
   xplot_scatter(xpdb = xpdb, group = group, quiet = quiet,
                 opt = data_opt(.problem = .problem, filter = only_obs(xpdb, .problem, quiet)),
-                mapping = aes_c(aes_string(x = xp_var(xpdb, .problem, type = 'ipred')$col, 
-                                           y = xp_var(xpdb, .problem, type = 'dv')$col), mapping),
+                mapping = aes_c(aes(x = .data[[xp_var(xpdb, .problem, type = 'ipred')$col]], 
+                                    y = .data[[xp_var(xpdb, .problem, type = 'dv')$col]]), mapping),
                 type = type, guide = guide, facets = facets, 
                 xscale = check_scales('x', log), 
                 yscale = check_scales('y', log), 
                 title = title, subtitle = subtitle, caption = caption, 
-                tag = tag, plot_name = as.character(match.call()[[1]]),
+                tag = tag, plot_name = stringr::str_remove(deparse(match.call()[[1]]), "(\\w+\\.*)+::"),
                 guide_slope = 1, ...)
 }
 
@@ -92,12 +92,12 @@ dv_vs_pred <- function(xpdb,
   
   xplot_scatter(xpdb = xpdb, group = group, quiet = quiet,
                 opt = data_opt(.problem = .problem, filter = only_obs(xpdb, .problem, quiet)),
-                mapping = aes_c(aes_string(x = xp_var(xpdb, .problem, type = 'pred')$col, 
-                                           y = xp_var(xpdb, .problem, type = 'dv')$col), mapping),
+                mapping = aes_c(aes(x = .data[[xp_var(xpdb, .problem, type = 'pred')$col]], 
+                                    y = .data[[xp_var(xpdb, .problem, type = 'dv')$col]]), mapping),
                 type = type, guide = guide, facets = facets, 
                 xscale = check_scales('x', log), 
                 yscale = check_scales('y', log), 
                 title = title, subtitle = subtitle, caption = caption,
-                tag = tag, plot_name = as.character(match.call()[[1]]),
+                tag = tag, plot_name = stringr::str_remove(deparse(match.call()[[1]]), "(\\w+\\.*)+::"),
                 guide_slope = 1, ...)
 }
